@@ -26,20 +26,21 @@ from dotenv import load_dotenv
 load_dotenv()
 
 # Add submodules to path
-_incept_multilingual_path = Path(__file__).parent / "submodules" / "incept-multilingual-generation"
+_submodules_path = Path(__file__).parent / "submodules"
 _reading_qc_path = Path(__file__).parent / "submodules" / "reading-question-qc"
 _edubench_path = Path(__file__).parent / "submodules" / "EduBench" / "code" / "evaluation"
 
-if str(_incept_multilingual_path) not in sys.path:
-    sys.path.insert(0, str(_incept_multilingual_path))
+# Add submodules root for incept_core imports
+if str(_submodules_path) not in sys.path:
+    sys.path.insert(0, str(_submodules_path))
 if str(_reading_qc_path) not in sys.path:
     sys.path.insert(0, str(_reading_qc_path))
 if str(_edubench_path) not in sys.path:
     sys.path.insert(0, str(_edubench_path))
 
-# Import from submodules
-from src.evaluator.v3 import call_single_shot_evaluator
-from src.evaluator.edubench import verify_answer_with_gpt4, get_normal_answer
+# Import from incept_core (extracted minimal files from incept-multilingual-generation)
+from incept_core.evaluator.v3 import call_single_shot_evaluator
+from incept_core.evaluator.edubench import verify_answer_with_gpt4, get_normal_answer
 from evaluation import TASK_PROMPT_TEMPLATES
 from qc_pipeline import QuestionQCAnalyzer
 
@@ -432,6 +433,118 @@ def _run_edubench_task(question_idx: int, task_type: str, question: UniversalGen
 
     return result
 
+
+def benchmark_parallel(request: UniversalEvaluationRequest, max_workers: int = 100) -> Dict[str, Any]:
+    """
+    Benchmark mode: Process all questions in parallel for maximum throughput.
+
+    Args:
+        request: UniversalEvaluationRequest with list of questions
+        max_workers: Number of parallel workers (default: 100)
+
+    Returns:
+        Dict with structure:
+        {
+            "request_id": str,
+            "total_questions": int,
+            "successful": int,
+            "failed": int,
+            "scores": List[Dict] - one score per question,
+            "failed_ids": List[str],
+            "evaluation_time_seconds": float
+        }
+    """
+    start_time = time.time()
+    request_id = str(uuid.uuid4())
+
+    logger.info(f"🚀 Benchmark mode: Processing {len(request.generated_questions)} questions with {max_workers} workers")
+
+    scores = []
+    failed_ids = []
+
+    def process_single_question(question):
+        """Process a single question and return result or error"""
+        try:
+            # Create a mini request with just this question
+            mini_request = UniversalEvaluationRequest(
+                submodules_to_run=request.submodules_to_run,
+                generated_questions=[question],
+                verbose=False  # Always use simplified mode for benchmarking
+            )
+
+            # Run evaluation
+            response = universal_unified_benchmark(mini_request)
+
+            # Extract the score
+            if question.id in response.evaluations:
+                eval_result = response.evaluations[question.id]
+
+                # Convert Pydantic models to dicts for JSON serialization
+                scores_dict = {}
+                for module in request.submodules_to_run:
+                    module_result = getattr(eval_result, module, None)
+                    if module_result is not None:
+                        # Convert Pydantic model to dict
+                        scores_dict[module] = module_result.model_dump(exclude_none=True)
+                    else:
+                        scores_dict[module] = None
+
+                return {
+                    "id": question.id,
+                    "success": True,
+                    "final_score": eval_result.final_score,
+                    "scores": scores_dict
+                }
+            else:
+                return {
+                    "id": question.id,
+                    "success": False,
+                    "error": "No evaluation result returned"
+                }
+        except Exception as e:
+            logger.error(f"Failed to process question {question.id}: {e}")
+            return {
+                "id": question.id,
+                "success": False,
+                "error": str(e)
+            }
+
+    # Process all questions in parallel with progress bar
+    with ThreadPoolExecutor(max_workers=max_workers) as executor:
+        results = list(tqdm(
+            executor.map(process_single_question, request.generated_questions),
+            total=len(request.generated_questions),
+            desc="Evaluating questions"
+        ))
+
+    # Collect results
+    for result in results:
+        if result["success"]:
+            scores.append({
+                "id": result["id"],
+                "final_score": result["final_score"],
+                "scores": result["scores"]
+            })
+        else:
+            failed_ids.append(result["id"])
+            logger.warning(f"Question {result['id']} failed: {result.get('error', 'Unknown error')}")
+
+    evaluation_time = time.time() - start_time
+
+    logger.info(f"✅ Benchmark complete: {len(scores)}/{len(request.generated_questions)} successful in {evaluation_time:.2f}s")
+
+    return {
+        "request_id": request_id,
+        "total_questions": len(request.generated_questions),
+        "successful": len(scores),
+        "failed": len(failed_ids),
+        "scores": scores,
+        "failed_ids": failed_ids,
+        "evaluation_time_seconds": evaluation_time,
+        "avg_score": sum(s["final_score"] for s in scores) / len(scores) if scores else 0.0
+    }
+
+
 def universal_unified_benchmark(request: UniversalEvaluationRequest) -> UniversalEvaluationResponse:
     """
     Main entry point for universal evaluation.
